# TODO:
# - how to add to the trusted service of the firewall?

%define _prefix	%{_usr}/lib/jenkins
%define workdir	%{_var}/lib/jenkins

Name:		jenkins
Version:	1.651.2
Release:	1%{?dist}
Summary:	Continous Build Server
# This is where to get the stable jenkins.war file
# http://mirrors.jenkins-ci.org/war-stable/
Source:		jenkins.%{version}.war
Source1:	jenkins.init.in
Source2:	jenkins.sysconfig.in
Source3:	jenkins.logrotate
Source4:	jenkins.repo
URL:		http://jenkins-ci.org/
Group:		Development/Tools/Building
License:	MIT/X License, GPL/CDDL, ASL2
BuildRoot:	%{_tmppath}/build-%{name}-%{version}
Obsoletes:  hudson
PreReq:		/usr/sbin/groupadd /usr/sbin/useradd
#PreReq:		%{fillup_prereq}
BuildRequires: shadow-utils
Requires: shadow-utils
BuildArch:	noarch

%description
Jenkins monitors executions of repeated jobs, such as building a software
project or jobs run by cron. Among those things, current Jenkins focuses on the
following two jobs:
- Building/testing software projects continuously, just like CruiseControl or
  DamageControl. In a nutshell, Jenkins provides an easy-to-use so-called
  continuous integration system, making it easier for developers to integrate
  changes to the project, and making it easier for users to obtain a fresh
  build. The automated, continuous build increases the productivity.
- Monitoring executions of externally-run jobs, such as cron jobs and procmail
  jobs, even those that are run on a remote machine. For example, with cron,
  all you receive is regular e-mails that capture the output, and it is up to
  you to look at them diligently and notice when it broke. Jenkins keeps those
  outputs and makes it easy for you to notice when something is wrong.




Authors:
--------
    Kohsuke Kawaguchi <Kohsuke.Kawaguchi@sun.com>

%prep
%setup -q -T -c

%build

%install
rm -rf "%{buildroot}"
%__install -D -m0644 "%{SOURCE0}" "%{buildroot}%{_prefix}/%{name}.war"
%__install -d "%{buildroot}%{workdir}"
%__install -d "%{buildroot}%{workdir}/plugins"

%__install -d "%{buildroot}/var/log/jenkins"
%__install -d "%{buildroot}/var/cache/jenkins"

%__install -D -m0755 "%{SOURCE1}" "%{buildroot}/etc/init.d/%{name}"
%__sed -i 's,@@WAR@@,%{_prefix}/%{name}.war,g' "%{buildroot}/etc/init.d/%{name}"
%__install -d "%{buildroot}/usr/sbin"
%__ln_s "../../etc/init.d/%{name}" "%{buildroot}/usr/sbin/rc%{name}"

%__install -D -m0600 "%{SOURCE2}" "%{buildroot}/etc/sysconfig/%{name}"
%__sed -i 's,@@HOME@@,%{workdir},g' "%{buildroot}/etc/sysconfig/%{name}"

%__install -D -m0644 "%{SOURCE3}" "%{buildroot}/etc/logrotate.d/%{name}"

mkdir -p %{buildroot}%{_mandir}/man1
%__install -D -m0644 "%{SOURCE4}" "%{buildroot}%{_mandir}/man1/%{name}.1.gz"

%pre
/usr/sbin/groupadd -r jenkins &>/dev/null || :
# SUSE version had -o here, but in Fedora -o isn't allowed without -u
/usr/sbin/useradd -g jenkins -s /bin/false -r -c "Jenkins Continuous Build server" \
	-d "%{workdir}" jenkins &>/dev/null || :

%post
/sbin/chkconfig --add jenkins

# If we have an old hudson install, rename it to jenkins
if test -d /var/lib/hudson; then
    # leave a marker to indicate this came from Hudson.
    # could be useful down the road
    # This also ensures that the .??* wildcard matches something
    touch /var/lib/hudson/.moving-hudson
    mv -f /var/lib/hudson/* /var/lib/hudson/.??* /var/lib/jenkins
    rmdir /var/lib/hudson
    find /var/lib/jenkins -user hudson -exec chown jenkins {} + || true
fi
if test -d /var/run/hudson; then
    mv -f /var/run/hudson/* /var/run/jenkins
    rmdir /var/run/hudson
fi


%preun
if [ "$1" = 0 ] ; then
    # if this is uninstallation as opposed to upgrade, delete the service
    /sbin/service jenkins stop > /dev/null 2>&1
    /sbin/chkconfig --del jenkins
fi
exit 0

%postun
if [ "$1" -ge 1 ]; then
    /sbin/service jenkins condrestart > /dev/null 2>&1
fi
exit 0

%clean
%__rm -rf "%{buildroot}"

%files
%defattr(-,root,root)
%dir %{_prefix}
%{_prefix}/%{name}.war
%attr(0755,jenkins,jenkins) %dir %{workdir}
%attr(0750,jenkins,jenkins) /var/log/jenkins
%attr(0750,jenkins,jenkins) /var/cache/jenkins
%config /etc/logrotate.d/%{name}
%config(noreplace) /etc/init.d/%{name}
%config(noreplace) /etc/sysconfig/%{name}
/usr/sbin/rc%{name}
%doc %{_mandir}/man1/%{name}.1.gz

%changelog
* Wed Jul 13 2016 Rory Thrasher <rthrashe@redhat.com> - 1.651.2-1
- Upgrade to 1.651.2 LTS
-- Fixes several security issues

* Tue Dec 15 2015 Rory Thrasher <rthrashe@redhat.com> - 1.625.3-1
- Upgrade to 1.625.3 LTS
-- Addresses CVE-2015-7536 CVE-2015-7537 CVE-2015-7538 CVE-2015-7539

* Thu Oct 02 2014 Troy Dawson <tdawson@redhat.com> - 1.609.1-1
- Upgrade to 1.609.1 LTS
-- Fixes over 9 security issues

* Thu Oct 02 2014 Troy Dawson <tdawson@redhat.com> - 1.565.3-1
- Upgrade to 1.565.3 LTS
-- Fixes over 13 security issues

* Tue Jun 24 2014 Troy Dawson <tdawson@redhat.com> - 1.554.2-1
- Upgrade to 1.554.2 LTS

* Mon Dec 16 2013 Troy Dawson (tdawson@redhat.com) - 1.532.1-1
- Upgrade to 1.532.1 LTS

* Fri May 03 2013 Troy Dawson (tdawson@redhat.com) - 1.509.1-1
- Upgrade to 1.509.1 LTS this fixes
  CVE-2013-0253 CVE-2013-1808

* Mon Mar 18 2013 Brenton Leanhardt <bleanhar@redhat.com> - 1.506-1
- Upgrading to 1.506 to address CVE-2013-0253

* Mon Feb 25 2013 Brenton Leanhardt <bleanhar@redhat.com> - 1.502-1
- Upgrading to 1.502 to address CVE-2013-0327 CVE-2013-0328 CVE-2013-0329
  CVE-2013-0330 CVE-2013-0331

* Wed Jan 2 2013 Brenton Leanhardt <bleanhar@redhat.com> - 1.498-1.1
- Upgrading to 1.498 to address CVE-2013-0158

* Wed Jan 2 2013 Brenton Leanhardt <bleanhar@redhat.com> - 1.491-1
- Upgrading to 1.491 to address CVE-2012-6072

* Wed Oct 31 2012 Thomas A. McGonagle <mcgonagle@redhat.com> - 1.488-2
- Added a jenkins init startup script manpage

* Mon Oct 29 2012 Brenton Leanhardt <bleanhar@redhat.com> 1.488-1
- Pulled in the latest package from upstream

* Wed Sep 28 2011 kk@kohsuke.org
- See [http://jenkins-ci.org/changelog] for complete details
